==> spring-boot-ext-1.2.71-sources.jar: cn/com/duibaboot/ext/autoconfigure/accesslog/AccessLogAutoConfiguration.java <==
package cn.com.duibaboot.ext.autoconfigure.accesslog;

import ch.qos.logback.classic.LoggerContext;
import ch.qos.logback.classic.joran.JoranConfigurator;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.boot.autoconfigure.condition.ConditionalOnResource;
import org.springframework.boot.autoconfigure.condition.ConditionalOnWebApplication;
import org.springframework.boot.web.servlet.FilterRegistrationBean;
import org.springframework.context.ApplicationListener;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.event.ContextRefreshedEvent;
import org.springframework.core.io.ClassPathResource;

import javax.servlet.DispatcherType;
import java.util.ArrayList;
import java.util.EnumSet;
import java.util.List;
import java.util.Properties;

/**
 *
 * 通用URL 日志打印,统一日志格式,用于收集日志,方便实时采集到大数据平台
 * Created by xuhengfei on 16/12/20.
 */
@Configuration
@ConditionalOnClass({LoggerContext.class})
@ConditionalOnResource(resources = "/logback/access-logback.xml")
@ConditionalOnWebApplication
public class AccessLogAutoConfiguration {

    private static Logger LOG=LoggerFactory.getLogger(AccessLogAutoConfiguration.class);

    @Configuration
    @ConditionalOnClass({LoggerContext.class})
    @ConditionalOnResource(resources = "/logback/access-logback.xml")
    @ConditionalOnWebApplication
    public static class AccessLogHttpFilterConfiguration{
        @Bean
        public FilterRegistrationBean acesslogHttpFilterConfigurer(){
            AccessLogFilter filter=new AccessLogFilter();
            FilterRegistrationBean registrationBean = new FilterRegistrationBean();
            registrationBean.setFilter(filter);
            List<String> urlPatterns=new ArrayList<String>();
            urlPatterns.add("/*");//拦截路径，可以添加多个
            registrationBean.setUrlPatterns(urlPatterns);
            registrationBean.setDispatcherTypes(EnumSet.of(DispatcherType.REQUEST));
            registrationBean.setOrder(100);


            try {
                Properties p = new Properties();
                p.load(new ClassPathResource("/accesslog_filter.properties").getInputStream());
                if(!p.isEmpty()){
                    filter.loadConfig(p);
                    LOG.info("load accesslog_filter.properties success");
                }
            }catch (Exception e){
                //ignore
            }


            return registrationBean;
        }
    }

    /**
     * 附加logback配置文件
     * @return
     */
    @Bean
    public ApplicationListener accesslogLogbackConfig() {
        return new ApplicationListener<ContextRefreshedEvent>(){

            private boolean flag = true;

            @Override
            public void onApplicationEvent(ContextRefreshedEvent applicationStartedEvent) {
                if(flag){
                    try {
                        LoggerContext loggerContext = (LoggerContext) LoggerFactory.getILoggerFactory();
                        JoranConfigurator configurator = new JoranConfigurator();
                        configurator.setContext(loggerContext);
                        //logback 添加新的配置文件
                        configurator.doConfigure(new ClassPathResource("/logback/access-logback.xml").getInputStream());
                    } catch (Exception e) {
                        LOG.error(e.getMessage(), e);
                    }
                    flag = false;
                }
            }
        };
    }
}

==> spring-boot-ext-1.2.236-sources.jar: cn/com/duibaboot/ext/autoconfigure/accesslog/AccessLogAutoConfiguration.java <==
package cn.com.duibaboot.ext.autoconfigure.accesslog;

import ch.qos.logback.classic.LoggerContext;
import ch.qos.logback.classic.joran.JoranConfigurator;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.boot.autoconfigure.condition.ConditionalOnResource;
import org.springframework.boot.autoconfigure.condition.ConditionalOnWebApplication;
import org.springframework.boot.web.servlet.FilterRegistrationBean;
import org.springframework.context.ApplicationListener;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.event.ContextRefreshedEvent;
import org.springframework.core.io.ClassPathResource;

import javax.servlet.DispatcherType;
import java.util.ArrayList;
import java.util.EnumSet;
import java.util.List;
import java.util.Properties;

/**
 *
 * 通用URL 日志打印,统一日志格式,用于收集日志,方便实时采集到大数据平台
 * Created by xuhengfei on 16/12/20.
 */
@Configuration
@ConditionalOnClass({LoggerContext.class})
@ConditionalOnResource(resources = "/logback/access-logback.xml")
@ConditionalOnWebApplication
public class AccessLogAutoConfiguration {

    private static final Logger logger = LoggerFactory.getLogger(AccessLogAutoConfiguration.class);

    @Configuration
    @ConditionalOnClass({LoggerContext.class})
    @ConditionalOnResource(resources = "/logback/access-logback.xml")
    @ConditionalOnWebApplication
    public static class AccessLogHttpFilterConfiguration{
        @Bean
        public FilterRegistrationBean acesslogHttpFilterConfigurer(){
            AccessLogFilter filter=new AccessLogFilter();
            FilterRegistrationBean registrationBean = new FilterRegistrationBean();
            registrationBean.setFilter(filter);
            List<String> urlPatterns=new ArrayList<>();
            urlPatterns.add("/*");//拦截路径，可以添加多个
            registrationBean.setUrlPatterns(urlPatterns);
            registrationBean.setDispatcherTypes(EnumSet.of(DispatcherType.REQUEST));
            registrationBean.setOrder(100);


            try {
                Properties p = new Properties();
                p.load(new ClassPathResource("/accesslog_filter.properties").getInputStream());
                if(!p.isEmpty()){
                    filter.loadConfig(p);
                    logger.info("load accesslog_filter.properties success");
                }
            }catch (Exception e){
                //ignore
            }


            return registrationBean;
        }
    }

    /**
     * 附加logback配置文件
     * @return
     */
    @Bean
    public ApplicationListener accesslogLogbackConfig() {
        return new ApplicationListener<ContextRefreshedEvent>(){

            private boolean flag = true;

            @Override
            public void onApplicationEvent(ContextRefreshedEvent applicationStartedEvent) {
                if(flag){
                    try {
                        LoggerContext loggerContext = (LoggerContext) LoggerFactory.getILoggerFactory();
                        JoranConfigurator configurator = new JoranConfigurator();
                        configurator.setContext(loggerContext);
                        //logback 添加新的配置文件
                        configurator.doConfigure(new ClassPathResource("/logback/access-logback.xml").getInputStream());
                    } catch (Exception e) {
                        logger.error(e.getMessage(), e);
                    }
                    flag = false;
                }
            }
        };
    }
}
